@@ -21,6 +21,8 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
+#include <glib/gi18n-lib.h>
+
 #include "gucharmap.h"
 #include "gucharmap-private.h"
 
@@ -58,7 +60,7 @@ static const gchar JAMO_T_TABLE[][4] = {
   "S", "SS", "NG", "J", "C", "K", "T", "P", "H"
 };
 
-G_CONST_RETURN gchar *
+const gchar *
 gucharmap_get_unicode_name (gunichar wc)
 {
   static gchar buf[32];
@@ -75,10 +77,21 @@ gucharmap_get_unicode_name (gunichar wc)
       g_snprintf (buf, sizeof (buf), "CJK UNIFIED IDEOGRAPH-%04X", wc);
       return buf;
     }
-  /* FIXME: handle U+F900..U+FAFF CJK COMPATIBILITY IDEOGRAPH U+%04X and
-   * U+2F800..U+2FA1D CJK COMPATIBILITY IDEOGRAPH U+%04X here,
-   * instead of via gucharmap_get_unicode_data_name below, to save some space?
-    */
+  else if ((wc >= 0xf900 && wc <= 0xfaff) ||
+           (wc >= 0x2f800 && wc <= 0x2fa1d)) {
+      g_snprintf (buf, sizeof (buf), "CJK COMPATIBILITY IDEOGRAPH-%04X", wc);
+      return buf;
+  }
+#if 0
+  else if (wc >= 0x17000 && wc <= 0x187ec) {
+      g_snprintf (buf, sizeof (buf), "TANGUT IDEOGRAPH-%05X", wc);
+      return buf;
+  }
+  else if (wc >= 0x18800 && wc <= 0x18af2) {
+      g_snprintf (buf, sizeof (buf), "TANGUT COMPONENT-%u", wc - 0x18800 + 1);
+      return buf;
+  }
+#endif
   else if (wc >= 0xac00 && wc <= 0xd7af)
     {
       /* compute hangul syllable name as per UAX #15 */
@@ -119,7 +132,7 @@ gucharmap_get_unicode_name (gunichar wc)
     }
 }
 
-G_CONST_RETURN gchar *
+const gchar *
 gucharmap_get_unicode_category_name (gunichar wc)
 {
   _gucharmap_intl_ensure_initialized ();
@@ -161,7 +174,7 @@ gucharmap_get_unicode_category_name (gunichar wc)
 }
 
 /* does a binary search on unicode_names */
-G_CONST_RETURN gchar *
+const gchar *
 gucharmap_get_unicode_data_name (gunichar uc)
 {
   gint min = 0;
@@ -217,7 +230,7 @@ gucharmap_get_unicode_version (gunichar uc)
   return GUCHARMAP_UNICODE_VERSION_UNASSIGNED;
 }
 
-G_CONST_RETURN gchar *
+const gchar *
 gucharmap_unicode_version_to_string (GucharmapUnicodeVersion version)
 {
   g_return_val_if_fail (version >= GUCHARMAP_UNICODE_VERSION_UNASSIGNED &&
@@ -239,7 +252,7 @@ gucharmap_get_unihan_count (void)
 
 /* does a binary search; also caches most recent, since it will often be
  * called in succession on the same character */
-static G_CONST_RETURN Unihan *
+static const Unihan *
 _get_unihan (gunichar uc)
 {
   static gunichar most_recent_searched;
@@ -283,43 +296,43 @@ gucharmap_get_unihan_count ()
   return 0;
 }
 
-G_CONST_RETURN gchar * 
+const gchar * 
 gucharmap_get_unicode_kDefinition (gunichar uc)
 {
   return "This feature was not compiled in.";
 }
 
-G_CONST_RETURN gchar * 
+const gchar * 
 gucharmap_get_unicode_kCantonese (gunichar uc)
 {
   return "This feature was not compiled in.";
 }
 
-G_CONST_RETURN gchar * 
+const gchar * 
 gucharmap_get_unicode_kMandarin (gunichar uc)
 {
   return "This feature was not compiled in.";
 }
 
-G_CONST_RETURN gchar * 
+const gchar * 
 gucharmap_get_unicode_kTang (gunichar uc)
 {
   return "This feature was not compiled in.";
 }
 
-G_CONST_RETURN gchar * 
+const gchar * 
 gucharmap_get_unicode_kKorean (gunichar uc)
 {
   return "This feature was not compiled in.";
 }
 
-G_CONST_RETURN gchar * 
+const gchar * 
 gucharmap_get_unicode_kJapaneseKun (gunichar uc)
 {
   return "This feature was not compiled in.";
 }
 
-G_CONST_RETURN gchar * 
+const gchar * 
 gucharmap_get_unicode_kJapaneseOn (gunichar uc)
 {
   return "This feature was not compiled in.";
@@ -329,7 +342,7 @@ gucharmap_get_unicode_kJapaneseOn (gunichar uc)
 
 /* does a binary search; also caches most recent, since it will often be
  * called in succession on the same character */
-static G_CONST_RETURN NamesList *
+static const NamesList *
 get_nameslist (gunichar uc)
 {
   static gunichar most_recent_searched;
@@ -402,7 +415,7 @@ gucharmap_get_nameslist_exes (gunichar uc)
  * Returns: (transfer container): newly allocated null-terminated array of gchar*
  * the items are const, but the array should be freed by the caller
  */
-G_CONST_RETURN gchar **
+const gchar **
 gucharmap_get_nameslist_equals (gunichar uc)
 {
   const NamesList *nl;
@@ -433,7 +446,7 @@ gucharmap_get_nameslist_equals (gunichar uc)
  * Returns: (transfer container): newly allocated null-terminated array of gchar*
  * the items are const, but the array should be freed by the caller
  */
-G_CONST_RETURN gchar **
+const gchar **
 gucharmap_get_nameslist_stars (gunichar uc)
 {
   const NamesList *nl;
@@ -464,7 +477,7 @@ gucharmap_get_nameslist_stars (gunichar uc)
  * Returns: (transfer container): newly allocated null-terminated array of gchar*
  * the items are const, but the array should be freed by the caller
  */
-G_CONST_RETURN gchar **
+const gchar **
 gucharmap_get_nameslist_pounds (gunichar uc)
 {
   const NamesList *nl;
@@ -495,7 +508,7 @@ gucharmap_get_nameslist_pounds (gunichar uc)
  * Returns: (transfer container): newly allocated null-terminated array of gchar*
  * the items are const, but the array should be freed by the caller
  */
-G_CONST_RETURN gchar **
+const gchar **
 gucharmap_get_nameslist_colons (gunichar uc)
 {
   const NamesList *nl;
