@@ -191,6 +191,17 @@ search_finish (GucharmapSearchDialog *search_dialog,
   g_simple_action_set_enabled (G_SIMPLE_ACTION (action), TRUE);
 }
 
+static void
+ensure_search_dialog (GucharmapWindow *guw)
+{
+  if (guw->search_dialog == NULL)
+    {
+      guw->search_dialog = gucharmap_search_dialog_new (guw);
+      g_signal_connect (guw->search_dialog, "search-start", G_CALLBACK (search_start), guw);
+      g_signal_connect (guw->search_dialog, "search-finish", G_CALLBACK (search_finish), guw);
+    }
+}
+
 static void
 search_find (GSimpleAction *action,
              GVariant      *parameter,
@@ -200,16 +211,12 @@ search_find (GSimpleAction *action,
 
   g_assert (GUCHARMAP_IS_WINDOW (guw));
 
-  if (guw->search_dialog == NULL)
-    {
-      guw->search_dialog = gucharmap_search_dialog_new (guw);
-      g_signal_connect (guw->search_dialog, "search-start", G_CALLBACK (search_start), guw);
-      g_signal_connect (guw->search_dialog, "search-finish", G_CALLBACK (search_finish), guw);
-    }
+  ensure_search_dialog (guw);
 
   gucharmap_search_dialog_present (GUCHARMAP_SEARCH_DIALOG (guw->search_dialog));
 }
 
+
 static void
 search_find_next (GSimpleAction *action,
                   GVariant      *parameter,
@@ -763,12 +770,6 @@ gucharmap_window_init (GucharmapWindow *guw)
                                    menu_entries, G_N_ELEMENTS (menu_entries),
                                    guw);
 
-  /* snap-to-power-of-two */
-  action = g_settings_create_action (guw->settings, "snap-cols-pow2");
-  g_action_map_add_action (G_ACTION_MAP (guw), action);
-  g_signal_connect (guw->settings, "changed::snap-cols-pow2",
-                    G_CALLBACK (snap_cols_pow2_changed), guw);
-
   /* Now the widgets */
   grid = gtk_grid_new ();
   gtk_container_add (GTK_CONTAINER (guw), grid);
@@ -829,6 +830,13 @@ gucharmap_window_init (GucharmapWindow *guw)
 
   gtk_window_set_has_resize_grip (GTK_WINDOW (guw), TRUE);
 
+  /* snap-to-power-of-two */
+  action = g_settings_create_action (guw->settings, "snap-cols-pow2");
+  g_action_map_add_action (G_ACTION_MAP (guw), action);
+  snap_cols_pow2_changed (guw->settings, "snap-cols-pow2", guw);
+  g_signal_connect (guw->settings, "changed::snap-cols-pow2",
+                    G_CALLBACK (snap_cols_pow2_changed), guw);
+
   /* read initial settings */
   /* font */
   g_settings_get (guw->settings, "font", "ms", &font);
@@ -909,3 +917,16 @@ gucharmap_window_set_font (GucharmapWindow *guw,
   gucharmap_charmap_set_font_desc (guw->charmap, font_desc);
   pango_font_description_free (font_desc);
 }
+
+void
+gucharmap_window_search (GucharmapWindow *guw,
+                         const char *str)
+{
+  g_return_if_fail (GUCHARMAP_IS_WINDOW (guw));
+  g_return_if_fail (str != NULL);
+
+  ensure_search_dialog (guw);
+  gucharmap_search_dialog_set_search (GUCHARMAP_SEARCH_DIALOG (guw->search_dialog), str);
+  gucharmap_search_dialog_start_search (GUCHARMAP_SEARCH_DIALOG (guw->search_dialog),
+                                        GUCHARMAP_DIRECTION_FORWARD);
+}
